@@ -1357,6 +1357,29 @@ typedef enum { /*< prefix=CLUTTER_ZOOM >*/
   CLUTTER_ZOOM_BOTH
 } ClutterZoomAxis;
 
+/**
+ * ClutterGestureTriggerEdge:
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_NONE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and there's no drag limit that
+ * will cause its cancellation;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_AFTER: Tell #ClutterGestureAction that
+ * it needs to wait until the drag threshold has been exceeded before
+ * considering that the gesture has begun;
+ * @CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE: Tell #ClutterGestureAction that
+ * the gesture must begin immediately and that it must be cancelled
+ * once the drag exceed the configured threshold.
+ *
+ * Enum passed to the clutter_gesture_action_set_threshold_trigger_edge()
+ * function.
+ *
+ * Since: 1.18
+ */
+typedef enum {
+  CLUTTER_GESTURE_TRIGGER_EDGE_NONE  = 0,
+  CLUTTER_GESTURE_TRIGGER_EDGE_AFTER,
+  CLUTTER_GESTURE_TRIGGER_EDGE_BEFORE
+} ClutterGestureTriggerEdge;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ENUMS_H__ */
